Module: URI
- Defined in:
- lib/URI/Generic/use_sslQ.rb
Overview
Notes:
-
Using the date from when first created in HTTP.get/post as the creation date.
Defined Under Namespace
Classes: Generic
Notes:
Using the date from when first created in HTTP.get/post as the creation date.
Classes: Generic